@@ -5,7 +5,7 @@ __license__ = 'GPL 3'
 __copyright__ = '2009, John Schember <john@nachtimwald.com>'
 __docformat__ = 'restructuredtext en'
 
-from PyQt5.Qt import QPrinter
+from qt.core import QPrinter
 
 UNITS = {
             'millimeter' : QPrinter.Unit.Millimeter,
